==> pdrtpy-2.2.5.tar.gz: pdrtpy-2.2.5/CITATION.md <==
If you use pdrtpy for a publication, you can use the following acknowledgment:

    This research made use of pdrtpy, The PhotoDissociation Region Toolbox, an open source PDR model and data analysis package.
    (Pound & Wolfire 2008; Kaufman, Wolfire, & Hollenbach 2006; Pound & Wolfire 2011)

The BibTex entries are:

    @INPROCEEDINGS{2008ASPC..394..654P,
           author = {{Pound}, M.~W. and {Wolfire}, M.~G.},
            title = "{The Photo Dissociation Region Toolbox}",
        booktitle = {Astronomical Data Analysis Software and Systems XVII},
             year = 2008,
           editor = {{Argyle}, R.~W. and {Bunclark}, P.~S. and {Lewis}, J.~R.},
           series = {Astronomical Society of the Pacific Conference Series},
           volume = {394},
            month = aug,
            pages = {654},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2008ASPC..394..654P},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }

    @ARTICLE{2006ApJ...644..283K,
           author = {{Kaufman}, Michael J. and {Wolfire}, Mark. G. and {Hollenbach}, David J.},
            title = "{[Si II], [Fe II], [C II], and H$_{2}$ Emission from Massive Star-forming Regions}",
          journal = {\apj},
         keywords = {Galaxies: ISM, Infrared: ISM, ISM: Atoms, ISM: Lines and Bands, ISM: Molecules},
             year = 2006,
            month = jun,
           volume = {644},
           number = {1},
            pages = {283-299},
              doi = {10.1086/503596},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2006ApJ...644..283K},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }
    
    @MISC{2011ascl.soft02022P,
           author = {{Pound}, M.~W. and {Wolfire}, M.~G.},
            title = "{PDRT: Photo Dissociation Region Toolbox}",
         keywords = {Software, NASA, Spitzer, ISO, SOFIA, Herschel},
             year = 2011,
            month = feb,
              eid = {ascl:1102.022},
            pages = {ascl:1102.022},
    archivePrefix = {ascl},
           eprint = {1102.022},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2011ascl.soft02022P},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }

==> pdrtpy-2.3.0.tar.gz: pdrtpy-2.3.0/CITATION.md <==
If you use pdrtpy for a publication, you can use the following acknowledgment:

    This research made use of pdrtpy, The PhotoDissociation Region Toolbox, an open source PDR model and data analysis package.
    (Pound & Wolfire 2022; Pound & Wolfire 2008; Kaufman, Wolfire, & Hollenbach 2006; Pound & Wolfire 2011)

The BibTex entries are:

    @INPROCEEDINGS{2008ASPC..394..654P,
           author = {{Pound}, M.~W. and {Wolfire}, M.~G.},
            title = "{The Photo Dissociation Region Toolbox}",
        booktitle = {Astronomical Data Analysis Software and Systems XVII},
             year = 2008,
           editor = {{Argyle}, R.~W. and {Bunclark}, P.~S. and {Lewis}, J.~R.},
           series = {Astronomical Society of the Pacific Conference Series},
           volume = {394},
            month = aug,
            pages = {654},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2008ASPC..394..654P},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }

    @ARTICLE{2006ApJ...644..283K,
           author = {{Kaufman}, Michael J. and {Wolfire}, Mark. G. and {Hollenbach}, David J.},
            title = "{[Si II], [Fe II], [C II], and H$_{2}$ Emission from Massive Star-forming Regions}",
          journal = {\apj},
         keywords = {Galaxies: ISM, Infrared: ISM, ISM: Atoms, ISM: Lines and Bands, ISM: Molecules},
             year = 2006,
            month = jun,
           volume = {644},
           number = {1},
            pages = {283-299},
              doi = {10.1086/503596},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2006ApJ...644..283K},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }
    
    @MISC{2011ascl.soft02022P,
           author = {{Pound}, M.~W. and {Wolfire}, M.~G.},
            title = "{PDRT: Photo Dissociation Region Toolbox}",
         keywords = {Software, NASA, Spitzer, ISO, SOFIA, Herschel},
             year = 2011,
            month = feb,
              eid = {ascl:1102.022},
            pages = {ascl:1102.022},
    archivePrefix = {ascl},
           eprint = {1102.022},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2011ascl.soft02022P},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }
